@@ -1,5 +1,5 @@
-import inspect
-from functools import wraps
+import sys, inspect
+from functools import partial
 
 
 __all__ = ['decorator']
@@ -41,7 +41,10 @@ class Call(object):
 
     def __getattr__(self, name):
         if not self._introspected:
-            self.__dict__.update(getcallargs(self._func, *self._args, **self._kwargs))
+            # Find real func to call getcallargs() on it
+            # We need to do it since our decorators don't preserve signature
+            func = unwrap(self._func)
+            self.__dict__.update(getcallargs(func, *self._args, **self._kwargs))
             self._introspected = True
         try:
             return self.__dict__[name]
@@ -55,6 +58,59 @@ def argcounts(func):
     return (len(spec.args), bool(spec.varargs), bool(spec.keywords))
 
 
+### Fix functools.wraps to make it safely work with callables without all the attributes
+
+# These are already safe in python 3.2
+if sys.version_info >= (3, 2):
+    from functools import update_wrapper, wraps
+else:
+    # These are for python 2, so list of attributes is far shorter.
+    # Python 3.2 and ealier will get reduced functionality, but we don't support it :)
+    WRAPPER_ASSIGNMENTS = ('__module__', '__name__', '__doc__')
+    WRAPPER_UPDATES = ('__dict__',)
+    # Copy-pasted these two from python 3.3 functools source code
+    def update_wrapper(wrapper,
+                       wrapped,
+                       assigned = WRAPPER_ASSIGNMENTS,
+                       updated = WRAPPER_UPDATES):
+        wrapper.__wrapped__ = wrapped
+        for attr in assigned:
+            try:
+                value = getattr(wrapped, attr)
+            except AttributeError:
+                pass
+            else:
+                setattr(wrapper, attr, value)
+        for attr in updated:
+            getattr(wrapper, attr).update(getattr(wrapped, attr, {}))
+        # Return the wrapper so this can be used as a decorator via partial()
+        return wrapper
+
+    def wraps(wrapped,
+              assigned = WRAPPER_ASSIGNMENTS,
+              updated = WRAPPER_UPDATES):
+        return partial(update_wrapper, wrapped=wrapped,
+                       assigned=assigned, updated=updated)
+
+
+### Backport of python 3.4 inspect.unwrap utility
+
+try:
+    from inspect import unwrap
+except ImportError:
+    # A simplified version, no stop keyword-only argument
+    def unwrap(func):
+        f = func  # remember the original func for error reporting
+        memo = set([id(f)]) # Memoise by id to tolerate non-hashable objects
+        while hasattr(func, '__wrapped__'):
+            func = func.__wrapped__
+            id_func = id(func)
+            if id_func in memo:
+                raise ValueError('wrapper loop when unwrapping {!r}'.format(f))
+            memo.add(id_func)
+        return func
+
+
 ### Backport of inspect.getcallargs for python 2.6
 
 try:
