@@ -1,8 +1,7 @@
 from datetime import datetime, timedelta
-from functools import wraps
 
-from .cross import imap
-from .decorators import decorator
+from .cross import imap, xrange
+from .decorators import decorator, wraps
 
 
 __all__ = ['raiser', 'ignore', 'silent', 'retry', 'fallback',
